#
# spec file for package udisks2
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _udevrulesdir %(pkg-config --variable=udevdir udev)/rules.d

Name:           udisks2
%define _name   udisks
Version:        2.0.0
Release:        0
Summary:        Disk Management Service, version 2
License:        GPL-2.0+
Group:          System/Daemons
Url:            http://www.freedesktop.org/wiki/Software/udisks
Source:         http://udisks.freedesktop.org/releases/%{_name}-%{version}.tar.bz2
# Needed to build the man pages
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool
BuildRequires:  libacl-devel
# For xsltproc
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.31.13
BuildRequires:  pkgconfig(glib-2.0) >= 2.31.13
BuildRequires:  pkgconfig(gudev-1.0) >= 165
BuildRequires:  pkgconfig(libatasmart) >= 0.17
BuildRequires:  pkgconfig(libsystemd-login) >= 44
BuildRequires:  pkgconfig(polkit-agent-1) >= 0.92
BuildRequires:  pkgconfig(polkit-gobject-1) >= 0.92
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
# sgdisk is called by udisksd to modify the partition tables... thus a needed tool.
Requires:       gptfdisk
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}

# Upstream First - Policy:
# Never add any patches to this package without the upstream commit id
# in the patch. Any patches added here without a very good reason to make
# an exception will be silently removed with the next version update.

%description
udisks provides a daemon, D-Bus API and command line tools
for managing disks and storage devices.

%package -n libudisks2-0
Summary:        UDisks Client Library, version 2
License:        LGPL-2.0+
Group:          System/Libraries
Recommends:     %{name} = %{version}

%description -n libudisks2-0
udisks provides a daemon, D-Bus API and command line tools
for managing disks and storage devices.

%package -n typelib-1_0-UDisks-2_0
Summary:        UDisks Client Library, version 2 -- Introspection bindings
License:        LGPL-2.0+
Group:          System/Libraries

%description -n typelib-1_0-UDisks-2_0
udisks provides a daemon, D-Bus API and command line tools
for managing disks and storage devices.

This package provides the GObject Introspection bindings for
the UDisks client library.

%package devel
Summary:        Disk Management Service, version 2 -- Development Files
License:        LGPL-2.0+
Group:          Development/Libraries/C and C++
Requires:       libudisks2-0 = %{version}

%description devel
udisks provides a daemon, D-Bus API and command line tools
for managing disks and storage devices.

%lang_package
%prep
%setup -q -n %{_name}-%{version}

%build
export V=1
%configure \
  --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print
%find_lang %{name}

%pre
%service_add_pre udisks2.service

%post
%service_add_post udisks2.service

%preun
%service_del_preun udisks2.service

%postun
%service_del_postun udisks2.service

%post -n libudisks2-0 -p /sbin/ldconfig

%postun -n libudisks2-0 -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING NEWS README
%{_unitdir}/udisks2.service
%{_udevrulesdir}/80-udisks2.rules
%{_sbindir}/umount.udisks2
%{_bindir}/udisksctl
%dir %{_libexecdir}/udisks2
%{_libexecdir}/udisks2/udisksd
%{_datadir}/bash-completion/completions/udisksctl
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.UDisks2.conf
%{_datadir}/dbus-1/system-services/org.freedesktop.UDisks2.service
%{_datadir}/polkit-1/actions/org.freedesktop.udisks2.policy
%{_mandir}/man1/udisksctl.1%{?ext_man}
%{_mandir}/man8/udisks.8%{?ext_man}
%{_mandir}/man8/udisksd.8%{?ext_man}
%attr(0770,root,root) %dir %{_localstatedir}/lib/udisks2

%files -n libudisks2-0
%defattr(-,root,root,-)
%doc AUTHORS COPYING NEWS README
%{_libdir}/libudisks2.so.*

%files -n typelib-1_0-UDisks-2_0
%defattr(-,root,root,-)
%{_libdir}/girepository-1.0/UDisks-2.0.typelib

%files devel
%defattr(-,root,root,-)
%{_includedir}/udisks2/
%{_libdir}/libudisks2.so
%{_libdir}/pkgconfig/udisks2.pc
%{_datadir}/gir-1.0/UDisks-2.0.gir
%doc %{_datadir}/gtk-doc/html/udisks2/

%files lang -f %{name}.lang

%changelog
